@@ -29,8 +29,9 @@
 
 #include <string.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include "gnome-program.h"
 #include "gnome-url.h"
@@ -112,6 +113,8 @@ gnome_help_display (const char    *file_name,
  *
  * Returns: %TRUE on success, %FALSE otherwise (in which case @error will
  * contain the actual error).
+ *
+ * Since: 2.2
  **/
 gboolean
 gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
@@ -185,7 +188,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 	 * and then falling back to the global help path if the first one fails.
 	 */
 
-	if (stat (local_help_path, &local_help_st) == 0) {
+	if (g_stat (local_help_path, &local_help_st) == 0) {
 		if (!S_ISDIR (local_help_st.st_mode)) {
 			g_set_error (error,
 				     GNOME_HELP_ERROR,
@@ -200,7 +203,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 	}
 
 	if (file == NULL) {
-		if (stat (global_help_path, &global_help_st) == 0) {
+		if (g_stat (global_help_path, &global_help_st) == 0) {
 			if (!S_ISDIR (global_help_st.st_mode)) {
 				g_set_error (error,
 					     GNOME_HELP_ERROR,
@@ -214,8 +217,8 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 			g_set_error (error,
 				     GNOME_HELP_ERROR,
 				     GNOME_HELP_ERROR_NOT_FOUND,
-				     _("Unable to find the help files in either %s "
-				       "or %s.  Please check your installation"),
+				     _("Unable to find help paths %s or %s. "
+				       "Please check your installation"),
 				     local_help_path,
 				     global_help_path);
 			goto out;
@@ -314,6 +317,8 @@ gnome_help_display_with_doc_id (GnomeProgram  *program,
  *
  * Returns: %TRUE on success, %FALSE otherwise (in which case @error will
  * contain the actual error).
+ *
+ * Since: 2.2
  */
 gboolean
 gnome_help_display_desktop_with_env (GnomeProgram  *program,
@@ -382,7 +387,7 @@ gnome_help_display_desktop_with_env (GnomeProgram  *program,
 
 	g_free (file);
 	g_free (url);
-	
+
 	return retval;
 }
 
@@ -434,6 +439,8 @@ gnome_help_display_desktop (GnomeProgram  *program,
  *
  * Returns: %TRUE on success, %FALSE otherwise (in which case @error will
  * contain the actual error).
+ *
+ * Since: 2.2
  */
 gboolean
 gnome_help_display_uri_with_env (const char  *help_uri,
@@ -476,7 +483,7 @@ gnome_help_display_uri (const char  *help_uri,
 
 /**
  * gnome_help_error_quark:
- * 
+ *
  * Returns: A #GQuark representing the domain of gnome-help errors.
  */
 GQuark
