@@ -7,14 +7,14 @@
 #include <libgnome/gnome-init.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 int
 main (int argc, char *argv[])
 {
   GError *err = NULL;
   char *uri;
-  
+
   if (argc < 2)
     {
       fprintf (stderr, "Usage: %s <url>\n", argv[0]);
